==> pf4-component-mapper-3.23.0.tgz: package/esm/sub-form/sub-form.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["fields", "title", "description", "validate", "component"];
import React from 'react';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import { Title } from "@patternfly/react-core/dist/dynamic/components/Title";
import { Grid } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import { GridItem } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import { TextContent } from "@patternfly/react-core/dist/dynamic/components/Text";
import { Text } from "@patternfly/react-core/dist/dynamic/components/Text";
import { TextVariants } from "@patternfly/react-core/dist/dynamic/components/Text";

var SubForm = function SubForm(_ref) {
  var fields = _ref.fields,
      title = _ref.title,
      description = _ref.description,
      _validate = _ref.validate,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, _excluded);

  var formOptions = useFormApi();
  return /*#__PURE__*/React.createElement(Grid, _extends({
    hasGutter: true
  }, rest), title && /*#__PURE__*/React.createElement(GridItem, {
    sm: 12
  }, /*#__PURE__*/React.createElement(Title, {
    headingLevel: "h2",
    size: "xl"
  }, title)), description && /*#__PURE__*/React.createElement(GridItem, {
    sm: 12
  }, /*#__PURE__*/React.createElement(TextContent, null, /*#__PURE__*/React.createElement(Text, {
    component: TextVariants.small,
    style: {
      marginBottom: 0
    }
  }, description))), formOptions.renderForm(fields, formOptions));
};

SubForm.propTypes = {
  fields: PropTypes.array.isRequired,
  name: PropTypes.string,
  title: PropTypes.node,
  description: PropTypes.node,
  validate: PropTypes.any,
  component: PropTypes.any
};
export default SubForm;

==> pf4-component-mapper-4.0.0.tgz: package/esm/sub-form/sub-form.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["fields", "title", "description", "validate", "component"];
import React from 'react';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import { Title } from "@patternfly/react-core/dist/dynamic/components/Title";
import { Grid } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import { GridItem } from "@patternfly/react-core/dist/dynamic/layouts/Grid";
import { Content } from "@patternfly/react-core/dist/dynamic/components/Content";
import { ContentVariants } from "@patternfly/react-core/dist/dynamic/components/Content";

var SubForm = function SubForm(_ref) {
  var fields = _ref.fields,
      title = _ref.title,
      description = _ref.description,
      _validate = _ref.validate,
      component = _ref.component,
      rest = _objectWithoutProperties(_ref, _excluded);

  var formOptions = useFormApi();
  return /*#__PURE__*/React.createElement(Grid, _extends({
    hasGutter: true
  }, rest), title && /*#__PURE__*/React.createElement(GridItem, {
    sm: 12
  }, /*#__PURE__*/React.createElement(Title, {
    headingLevel: "h2",
    size: "xl"
  }, title)), description && /*#__PURE__*/React.createElement(GridItem, {
    sm: 12
  }, /*#__PURE__*/React.createElement(Content, null, /*#__PURE__*/React.createElement(Content, {
    component: ContentVariants.small,
    style: {
      marginBottom: 0
    }
  }, description))), formOptions.renderForm(fields, formOptions));
};

SubForm.propTypes = {
  fields: PropTypes.array.isRequired,
  name: PropTypes.string,
  title: PropTypes.node,
  description: PropTypes.node,
  validate: PropTypes.any,
  component: PropTypes.any
};
export default SubForm;
